@@ -102,7 +102,6 @@ def rule(
                 output.append(f"{key}={val}")
     return ",".join(output)
 
-
 class gram():
     def __init__(self, value):
         self.value = value
@@ -219,7 +218,7 @@ na = gram('na')
 location = gram('location')
 time = gram('time')
 link = gram('link')
-
+one = gram('1')
 
 _conll = gram('<conll>')
 _colon = gram('<colon>')
@@ -383,4 +382,37 @@ sg = gram('sg')
 
 pri = gram('pri')
 sec = gram('sec')
-ter = gram('ter')
\ No newline at end of file
+ter = gram('ter')
+
+vint = gram('int')
+
+abl = gram('abl')
+adl = gram('adl')
+locat = gram('locat')
+perl = gram('perl')
+dur = gram('dur')
+temp = gram('temp')
+mod = gram('mod')
+
+perf = gram('perf')
+imperf = gram('imperf')
+
+neg = gram('neg')
+aff = gram('aff')
+
+indicative = gram('indicative')
+imperative = gram('imperative')
+conditional = gram('conditional')
+
+past = gram('past')
+pres = gram('pres')
+fut = gram('fut')
+
+proper = gram('proper')
+pronoun = gram('pronoun')
+common = gram('common')
+
+count = gram('count')
+mass = gram('mass')
+
+tt = gram
\ No newline at end of file
